@@ -5,7 +5,7 @@
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
 ;; Maintainer: Protesilaos Stavrou <info@protesilaos.com>
 ;; URL: https://github.com/protesilaos/denote-sequence
-;; Version: 0.0.0.1
+;; Version: 0.1.0
 ;; Package-Requires: ((emacs "28.1") (denote "3.1.0"))
 
 ;; This file is NOT part of GNU Emacs.
@@ -61,6 +61,7 @@
 (defgroup denote-sequence ()
   "Sequence notes or Folgezettel with Denote."
   :group 'denote
+  :link '(info-link "(denote) top")
   :link '(info-link "(denote-sequence) top")
   :link '(url-link :tag "Denote homepage" "https://protesilaos.com/emacs/denote")
   :link '(url-link :tag "Denote Sequence homepage" "https://protesilaos.com/emacs/denote-sequence"))
@@ -352,7 +353,10 @@ depth given SEQUENCE."
 (defun denote-sequence--get-files (&optional files)
   "Return list of files or buffers in the variable `denote-directory'.
 With optional FILES only consider those, otherwise use `denote-directory-files'."
-  (delete-dups (append (denote--buffer-file-names) (or files (denote-directory-files)))))
+  (let* ((denote-directory (or denote-use-directory (denote-directory)))
+         (files (denote-directory-files))
+         (buffers (denote--buffer-file-names)))
+    (delete-dups (append buffers files))))
 
 (defun denote-sequence-get-all-files (&optional files)
   "Return all files in variable `denote-directory' with a sequence.
@@ -513,9 +517,11 @@ optional PREPEND-DELIMITER is non-nil, prepend the equals sign to the
 number if `denote-sequence-scheme' is numeric."
   (pcase denote-sequence-scheme
     ('numeric (if prepend-delimiter "=1" "1"))
-    ('alphanumeric (if (denote-sequence--alphanumeric-partial-p (substring sequence -1))
-                       "1"
-                     "a"))))
+    ('alphanumeric
+     (cond
+      ((null sequence) "1")
+      ((and sequence (denote-sequence--alphanumeric-partial-p (substring sequence -1))) "1")
+      (t "a")))))
 
 (defun denote-sequence--get-new-parent (&optional sequences)
   "Return a new to increment largest among sequences.
